==> restinpeace_0.3.1-0.tar.gz: restinpeace-0.3.1/src/opt/rip/rest_in_peace_gui.py <==
# -*- coding: utf-8 -*-

from PyQt4 import QtCore, QtGui

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.resize(0, 0)
        MainWindow.setMaximumSize(QtCore.QSize(800, 800))
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout = QtGui.QGridLayout(self.centralwidget)

        self.layout_top = QtGui.QVBoxLayout()

        self.checkBoxGSMAlarm = QtGui.QCheckBox(self.centralwidget)
        self.checkBoxGSMAlarm.setChecked(False)
#        self.checkBoxGSMAlarm.setMinimumSize(QtCore.QSize(0, 0))
        self.layout_top.addWidget(self.checkBoxGSMAlarm)


        self.layout_cellid = QtGui.QHBoxLayout()

        font = QtGui.QFont()
        font.setPointSize(30)
        self.spinBoxCellID = QtGui.QSpinBox(self.centralwidget)
        self.spinBoxCellID.setEnabled(False)
        self.spinBoxCellID.setFont(font)
        self.spinBoxCellID.setMinimumSize(QtCore.QSize(200, 80))
        self.spinBoxCellID.setFrame(False)
        self.spinBoxCellID.setAlignment(QtCore.Qt.AlignCenter)
        self.spinBoxCellID.setReadOnly(True)
        self.spinBoxCellID.setButtonSymbols(QtGui.QAbstractSpinBox.NoButtons)
        self.spinBoxCellID.setMaximum(9999999)
        self.spinBoxCellID.setProperty("value", 0)
        self.layout_cellid.addWidget(self.spinBoxCellID)

        self.pushButtonFav = QtGui.QPushButton(self.centralwidget)
        self.pushButtonFav.setEnabled(False)
        self.layout_cellid.addWidget(self.pushButtonFav)

        self.layout_top.addLayout(self.layout_cellid)


        self.labelFav = QtGui.QLabel(self.centralwidget)
#        self.labelFav.setMinimumSize(QtCore.QSize(0, 0))
        self.labelFav.setMaximumSize(QtCore.QSize(800, 60))

        font.setPointSize(12)
        self.labelFav.setFont(font)
        self.labelFav.setAlignment(QtCore.Qt.AlignCenter)
        self.layout_top.addWidget(self.labelFav)

        self.comboBoxFav = QtGui.QComboBox(self.centralwidget)
#        self.comboBoxFav.setMinimumSize(QtCore.QSize(75, 0))
        self.comboBoxFav.setEditable(True)
        self.comboBoxFav.setInsertPolicy(QtGui.QComboBox.InsertAtTop)
        self.layout_top.addWidget(self.comboBoxFav)

        self.layout_alarm = QtGui.QHBoxLayout()

        self.checkBoxAlarm = QtGui.QCheckBox(self.centralwidget)
        self.checkBoxAlarm.setChecked(False)
        self.layout_alarm.addWidget(self.checkBoxAlarm)

        self.checkBoxLogging = QtGui.QCheckBox(self.centralwidget)
        self.layout_alarm.addWidget(self.checkBoxLogging)

        self.layout_top.addLayout(self.layout_alarm)



        self.pushButtonStart = QtGui.QPushButton(self.centralwidget)
#        self.pushButtonStart.setMinimumSize(QtCore.QSize(20, 100))
        self.layout_top.addWidget(self.pushButtonStart)
        self.gridLayout.addLayout(self.layout_top, 0, 1, 1, 1)

        MainWindow.setCentralWidget(self.centralwidget)
        self.statusbar = QtGui.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.menuBar = QtGui.QMenuBar(MainWindow)
        self.menuBar.setGeometry(QtCore.QRect(0, 0, 0, 18))
        self.menuMenu = QtGui.QMenu(self.menuBar)
        self.menuMenu.setObjectName("menuMenu")
        MainWindow.setMenuBar(self.menuBar)
        self.actionQuit = QtGui.QAction(MainWindow)
        self.actionMenuAbout = QtGui.QAction(MainWindow)
        self.actionMenuTips = QtGui.QAction(MainWindow)
        self.actionMenuEdit = QtGui.QAction(MainWindow)
        self.menuMenu.addAction(self.actionMenuAbout)
        self.menuMenu.addAction(self.actionMenuTips)
        self.menuMenu.addAction(self.actionMenuEdit)
        self.menuBar.addAction(self.menuMenu.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Rest In Peace", None, QtGui.QApplication.UnicodeUTF8))
        self.labelFav.setText(QtGui.QApplication.translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:12pt; font-weight:600;\">Choose from Favorites</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:12pt;\">(Or type name to save with current CellID)</span></p></body></html>", None, QtGui.QApplication.UnicodeUTF8))
        self.pushButtonFav.setText(QtGui.QApplication.translate("MainWindow", "Add CellID"
, None, QtGui.QApplication.UnicodeUTF8))
        self.checkBoxAlarm.setText(QtGui.QApplication.translate("MainWindow", "Alarm required?", None, QtGui.QApplication.UnicodeUTF8))
        self.checkBoxGSMAlarm.setText(QtGui.QApplication.translate("MainWindow", "GSM Alarm", None, QtGui.QApplication.UnicodeUTF8))
        self.checkBoxLogging.setText(QtGui.QApplication.translate("MainWindow", "Log To File", None, QtGui.QApplication.UnicodeUTF8))
        self.pushButtonStart.setText(QtGui.QApplication.translate("MainWindow", "Go!!!", None, QtGui.QApplication.UnicodeUTF8))
        self.menuMenu.setTitle(QtGui.QApplication.translate("MainWindow", "Menu", None, QtGui.QApplication.UnicodeUTF8))
#        self.actionQuit.setText(QtGui.QApplication.translate("MainWindow", "Quit", None, QtGui.QApplication.UnicodeUTF8))
        self.actionMenuAbout.setText(QtGui.QApplication.translate("MainWindow", "About", None, QtGui.QApplication.UnicodeUTF8))
        self.actionMenuTips.setText(QtGui.QApplication.translate("MainWindow", "Tips", None, QtGui.QApplication.UnicodeUTF8))
        self.actionMenuEdit.setText(QtGui.QApplication.translate("MainWindow", "Edit", None, QtGui.QApplication.UnicodeUTF8))

==> restinpeace_0.3.3-0.tar.gz: restinpeace-0.3.3/src/opt/rip/rest_in_peace_gui.py <==
# -*- coding: utf-8 -*-

from PyQt4 import QtCore, QtGui

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.resize(0, 0)
        MainWindow.setMaximumSize(QtCore.QSize(800, 800))
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout = QtGui.QGridLayout(self.centralwidget)

        self.layout_top = QtGui.QVBoxLayout()

        self.checkBoxGSMAlarm = QtGui.QCheckBox(self.centralwidget)
#        self.checkBoxGSMAlarm.setChecked(False)
#        self.checkBoxGSMAlarm.setMinimumSize(QtCore.QSize(0, 0))
        self.layout_top.addWidget(self.checkBoxGSMAlarm)


        self.layout_cellid = QtGui.QHBoxLayout()

        font = QtGui.QFont()
        font.setPointSize(30)
        self.spinBoxCellID = QtGui.QSpinBox(self.centralwidget)
        self.spinBoxCellID.setEnabled(False)
        self.spinBoxCellID.setFont(font)
        self.spinBoxCellID.setMinimumSize(QtCore.QSize(200, 80))
        self.spinBoxCellID.setFrame(False)
        self.spinBoxCellID.setAlignment(QtCore.Qt.AlignCenter)
        self.spinBoxCellID.setReadOnly(True)
        self.spinBoxCellID.setButtonSymbols(QtGui.QAbstractSpinBox.NoButtons)
        self.spinBoxCellID.setMaximum(9999999)
        self.spinBoxCellID.setProperty("value", 0)
        self.layout_cellid.addWidget(self.spinBoxCellID)

        self.pushButtonFav = QtGui.QPushButton(self.centralwidget)
        self.pushButtonFav.setEnabled(False)
        self.layout_cellid.addWidget(self.pushButtonFav)

        self.layout_top.addLayout(self.layout_cellid)


        self.labelFav = QtGui.QLabel(self.centralwidget)
#        self.labelFav.setMinimumSize(QtCore.QSize(0, 0))
        self.labelFav.setMaximumSize(QtCore.QSize(800, 60))

        font.setPointSize(12)
        self.labelFav.setFont(font)
        self.labelFav.setAlignment(QtCore.Qt.AlignCenter)
        self.layout_top.addWidget(self.labelFav)

        self.comboBoxFav = QtGui.QComboBox(self.centralwidget)
#        self.comboBoxFav.setMinimumSize(QtCore.QSize(75, 0))
        self.comboBoxFav.setEditable(True)
        self.comboBoxFav.setInsertPolicy(QtGui.QComboBox.InsertAtTop)
        self.layout_top.addWidget(self.comboBoxFav)

#        self.layout_alarm = QtGui.QHBoxLayout()
#        self.checkBoxAlarm = QtGui.QCheckBox(self.centralwidget)
##        self.checkBoxAlarm.setChecked(False)
#        self.layout_alarm.addWidget(self.checkBoxAlarm)
#        self.layout_top.addLayout(self.layout_alarm)

        self.pushButtonStart = QtGui.QPushButton(self.centralwidget)
#        self.pushButtonStart.setMinimumSize(QtCore.QSize(20, 100))
        self.layout_top.addWidget(self.pushButtonStart)

        self.layout_bottom = QtGui.QHBoxLayout()
        self.checkBoxLogging = QtGui.QCheckBox(self.centralwidget)
        self.layout_bottom.addWidget(self.checkBoxLogging)
        self.layout_top.addLayout(self.layout_bottom)

        self.gridLayout.addLayout(self.layout_top, 0, 1, 1, 1)

        MainWindow.setCentralWidget(self.centralwidget)
        self.statusbar = QtGui.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.menuBar = QtGui.QMenuBar(MainWindow)
        self.menuBar.setGeometry(QtCore.QRect(0, 0, 0, 18))
        self.menuMenu = QtGui.QMenu(self.menuBar)
        self.menuMenu.setObjectName("menuMenu")
        MainWindow.setMenuBar(self.menuBar)
        self.actionQuit = QtGui.QAction(MainWindow)
        self.actionMenuAbout = QtGui.QAction(MainWindow)
        self.actionMenuTips = QtGui.QAction(MainWindow)
        self.actionMenuEdit = QtGui.QAction(MainWindow)
        self.menuMenu.addAction(self.actionMenuAbout)
        self.menuMenu.addAction(self.actionMenuTips)
        self.menuMenu.addAction(self.actionMenuEdit)
        self.menuBar.addAction(self.menuMenu.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Rest In Peace", None, QtGui.QApplication.UnicodeUTF8))
        self.labelFav.setText(QtGui.QApplication.translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"body { white-space: pre-wrap; font-size: 20px; padding: 5px 0px; }\n"
"</style></head><body>\n"
"Choose existing group or type new name</body></html>", None, QtGui.QApplication.UnicodeUTF8))
        self.pushButtonFav.setText(QtGui.QApplication.translate("MainWindow", "Add CellID to group"
, None, QtGui.QApplication.UnicodeUTF8))
#        self.checkBoxAlarm.setText(QtGui.QApplication.translate("MainWindow", "Alarm required?", None, QtGui.QApplication.UnicodeUTF8))
        self.checkBoxGSMAlarm.setText(QtGui.QApplication.translate("MainWindow", "GSM Alarm", None, QtGui.QApplication.UnicodeUTF8))
        self.checkBoxLogging.setText(QtGui.QApplication.translate("MainWindow", "Log To /home/user/MyDocs/restinpeace_cellid_log.txt", None, QtGui.QApplication.UnicodeUTF8))
        self.pushButtonStart.setText(QtGui.QApplication.translate("MainWindow", "Click to start watching for a selected group", None, QtGui.QApplication.UnicodeUTF8))
        self.menuMenu.setTitle(QtGui.QApplication.translate("MainWindow", "Menu", None, QtGui.QApplication.UnicodeUTF8))
#        self.actionQuit.setText(QtGui.QApplication.translate("MainWindow", "Quit", None, QtGui.QApplication.UnicodeUTF8))
        self.actionMenuAbout.setText(QtGui.QApplication.translate("MainWindow", "About", None, QtGui.QApplication.UnicodeUTF8))
        self.actionMenuTips.setText(QtGui.QApplication.translate("MainWindow", "Tips", None, QtGui.QApplication.UnicodeUTF8))
        self.actionMenuEdit.setText(QtGui.QApplication.translate("MainWindow", "Edit groups", None, QtGui.QApplication.UnicodeUTF8))
